==> mesian-v0.1.1.tar.bz2: mesian-v0.1.1/www-data/module/message/function/do.php <==
<?

//--------------------------------------------------
// argument

// $var["to"] : one or multiple address seperated by ','.
// $var["cc"]
// $var["subject"]
// $var["body"]

// $payload["tmp_name"] -> tmp file. : $_FILES["payload"]["tmp_name"]
// $payload["type"]
// $payload["name"]

// $isHtml

include_once $global["root"] . "/include/print_time.php";
include_once $global["root"] . "/include/print_array.php";
//include_once $global["root"] . "/module/message/function/xmlrpc.php";
include_once $global["root"] . "/module/message/function/etc.php";

include_once $global["root"] . "/lib/EmailData.php";
include_once $global["root"] . "/lib/Payload.php";
include_once $global["root"] . "/lib/Address.php";
include_once $global["root"] . "/lib/Messages.php";

function send_mail ($var) {
	global $global;

	$Template = new Template;
	$DB = new MySQLdb;

	$timestamp = mktime();

	// pre-defined value
	// make message id
	$message_id = mktime() . rand();

	////////////////////////////////////////////////////////////////////
	// make message header.
	$msg["Message_Id"] = "<" . $message_id . "@" . $_SESSION["config_domain"] . ">";
	$msg["Date"] = print_time($timestamp, "mail");
	$msg["User_Agent"] = $global["User-Agent"];

	$boundary = "--------" . md5($_SESSION["config_address"]);

	$msg["Content_Type"] = "multipart/mixed;\n boundary=\"" . $boundary . "\"";
	$msg["boundaryEnd"] = "--" . $boundary . "--\n";

	// register value
	$msg["From"] = $_SESSION["config_address"];
	$msg["Reply_To"] = $_SESSION["config_address"];
	$msg["Subject"] = $var["subject"];
	$msg["lang"] = "ko-KR";

	if ($_SESSION["config_full_name"]) {
		$msg["full_From"] =
			sprintf("\"%s\" <%s>", $_SESSION["config_full_name"], $_SESSION["config_address"]);
	} else {
		$msg["full_From"] = $_SESSION["config_address"];
	}
	////////////////////////////////////////////////////////////////////
	// make a multiple reciepient.
	$a = explode(",", $var["to"]);

	$Address = new Address;
	if (is_array($a) and count($a) > 0) {
		while (list($i, $j) = each($a)) {
			if (! trim($j)) continue;
			if (! $Address->check_valid($j)) continue;
			$tmp["To"][] = $j;
		}
	} else {
		$tmp["To"][] = $var["to"];
	}

	// all message will be treated as multipart/mixed message.
	// message body
	$b["boundary"] = $boundary;
	$b["charset"] = "euc-kr";
	$b["type"] = "text/html";
	$b["encoding"] = "base64";

	// encode body.
	if (! $var["delSignature"] or $var["delSignature"] == "") {
		$var1["signature"] = $_SESSION["config_signature"];
	}

	$var1["body"] = $var["body"];
	$var1["message_id"] = $message_id;

	$ED = new EmailData;

	$b["body"] =
		$ED->encode(
			$Template->generate("/module/message/template/messageBody_preEncoded", $var1)
		);

	// make body
	$msg["body"] = $Template->generate("/module/message/template/messageBody", $b);
	/////////////////////////////////////////////////////////////////////////////////

	// paylaod handling.
	if (is_array($_SESSION["user_payload"]) and count($_SESSION["user_payload"]) > 0) {
		$Payload = new Payload();
		$msg["payload"] = $Payload->message_form($boundary);
	}

	$Messages = new Messages;

	while (list($i, $j) = each($tmp["To"])) {
		$msg["To"] = $j;
		$c = $Template->generate("/module/message/template/message", $msg);
		$entireMessage = addslashes($c);

		$SQL_INSERT_QUEUE =
			"insert into mail_queueOutgoing (Fromaddr, Toaddr, entireMessage, message_id)
				values('%s', '%s', '%s', '%s')";

		$DB->transaction_start(true);
		$DB->query(
			sprintf($SQL_INSERT_QUEUE,
				$msg["From"], $j, $entireMessage, $message_id
			)
		);

		$DB->transaction_end();

		// insert messsage into sent directory.
		$Messages->insert_message_into_sent_directory($c, $message_id);

		unset($c);
		unset($msg);
		unset($entireMessage);
	}

	/*
	if ($DB->retval) {
		sendmailThruXMLRPC($global["sendmail"]["host"], $global["sendmail"]["port"]);
		$retval = true;
	} else {
		$retval = false;
	}
	*/


	$retval = true;

	return $retval;

}

function getContent($no, $method="") {
	global $global;

	$DB = new MySQLdb;

	//-------------------------------------------------- sql
	$SQL_GET_CONTENT_CID =
		"select SQL_CACHE isCid, cid, headerCid from mail_%s where no = '%d'";
	$SQL_GET_CONTENT_PAYLOAD = "select SQL_CACHE isPayload, payload, headerPayload
				from mail_%s where no = '%d'";
	$SQL_GET_CONTENT_HTML =
		"select SQL_CACHE htmlBody, isCid, headerCid from mail_%s where no = '%d'";

	//-------------------------------------------------- sql
	switch ($method) {

		case ("cid") :
			$a = $DB->fetch_one(
				sprintf($SQL_GET_CONTENT_CID, $_SESSION["config_id"], $no));

			if ($a["isCid"] == 0) exit;

			$b = parseContent($a["headerCid"], "cid");
			$data = retrieveContent($a["cid"], $n, "cid");

			$type = $b[$n]["type"];
			$filename = $b[$n]["filename"];

		break;
		case ("payload") :
			$a = $DB->fetch_one(
				sprintf($SQL_GET_CONTENT_PAYLOAD, $_SESSION["config_id"], $no));

			if ($a["isPayload"] == 0) exit;

			$b = parseContent($a["headerPayload"], "payload");
			$data = retrieveContent($a["payload"], $n, "payload");

			$type = $b[$n]["type"];
			$filename = $b[$n]["filename"];

		break;
		case ("html") :

			$a = $DB->fetch_one(
				sprintf($SQL_GET_CONTENT_HTML, $_SESSION["config_id"], $no));

			if ($a["isCid"]) $f = parseContent($a["headerCid"], "cid"); // check cid

			$g = $a["htmlBody"];
			$n = count($f);
			for ($i = 0; $i < $n; $i++) {

				$h = $_SESSION["user_www_url"] .
					"/module/message/action/getContent?method=cid&no=" . $no . "&n=" . $i;

				$g = ereg_replace("cid:" . $f[$i]["id"], $h, $g);

				// prevent mugling of "img src script".
				$g = preg_replace("/<img class=\"mesian\" .*src=[a-z0-9\"']*script:[^>]+>/i", "", $g);
			}

			$type = "text/html";

			// remove html header & body tag.
			$g = eregi_replace("<html>.*</head>", "", $g);
			$g = eregi_replace("<body[ a-z0-9=\"'#][ a-z0-9=\"'#]*>", "", $g);

			$g = eregi_replace("<a ", "<a target=awindow ", $g); // altering link.
			$k = eregi_replace("<script", "<span", $g); // preventing script kiddy.

			// remove "delivery notification service" code
			if ($_SESSION["user_directory"] == $global["directory"]["sent"]) {
				$data = eregi_replace(
					sprintf("<img class=\"mesian\" src=\"http://[a-z0-9./-][a-z0-9./-]*\?a=%s*&b=[0-9][0-9]*\" width=1 height=1>",
						$_SESSION["config_id"]),
					"", $k);
			} else {
				$data = $k;
			}
		break;
	}

	return $data;
}

?>

==> mesian-v0.1.2.tar.bz2: mesian-v0.1.2/www-data/module/message/function/do.php <==
<?

//--------------------------------------------------
// argument

// $var["to"] : one or multiple address seperated by ','.
// $var["cc"]
// $var["subject"]
// $var["body"]

// $payload["tmp_name"] -> tmp file. : $_FILES["payload"]["tmp_name"]
// $payload["type"]
// $payload["name"]

// $isHtml

include_once $global["root"] . "/include/print_time.php";
include_once $global["root"] . "/include/print_array.php";
//include_once $global["root"] . "/module/message/function/xmlrpc.php";
include_once $global["root"] . "/module/message/function/etc.php";

include_once $global["root"] . "/lib/EmailData.php";
include_once $global["root"] . "/lib/Payload.php";
include_once $global["root"] . "/lib/Address.php";
include_once $global["root"] . "/lib/Extend_message.php";
include_once $global["root"] . "/lib/Mail_Message.php";

function send_mail ($var) {
	global $global;

	$DB = new MySQLdb;

	$Messages = new Extend_message;
	$Mail = new Compose_Message;

	$Mail->set_params("Subject", $var["Subject"]);
	$Mail->set_params("body", $var["body"]);
	$Mail->set_attr("delSignature", $var["delSignature"]);

	$retval = true;
	while (list($i, $j) = each($var["To"])) {

		if (! $retval) continue;

		$Mail->set_params("To", $j);
		$msg = $Mail->pack();
		$entireMessage = addslashes($msg);

		$SQL_INSERT_QUEUE =
			"insert into mail_queueOutgoing (Fromaddr, Toaddr, entireMessage, message_id)
				values('%s', '%s', '%s', '%s')";

		$DB->transaction_start(true);
		$DB->query(
			sprintf($SQL_INSERT_QUEUE,
				$_SESSION["config_address"], $j, $entireMessage, $Mail->message_id
			)
		);

		$retval = $DB->retval;
		$DB->transaction_end();

		// insert messsage into sent directory.
		$Messages->insert_message_into_sent_directory($msg, $Mail->message_id);

		unset($msg);
		unset($entireMessage);
	}

	unset($Mail);

	return $retval;
}

function getContent($no, $method="") {
	global $global;

	$DB = new MySQLdb;

	//-------------------------------------------------- sql
	$SQL_GET_CONTENT_CID =
		"select SQL_CACHE isCid, cid, headerCid from mail_%s where no = '%d'";
	$SQL_GET_CONTENT_PAYLOAD = "select SQL_CACHE isPayload, payload, headerPayload
				from mail_%s where no = '%d'";
	$SQL_GET_CONTENT_HTML =
		"select SQL_CACHE htmlBody, isCid, headerCid from mail_%s where no = '%d'";

	//-------------------------------------------------- sql
	switch ($method) {

		case ("cid") :
			$a = $DB->fetch_one(
				sprintf($SQL_GET_CONTENT_CID, $_SESSION["config_id"], $no));

			if ($a["isCid"] == 0) exit;

			$b = parseContent($a["headerCid"], "cid");
			$data = retrieveContent($a["cid"], $n, "cid");

			$type = $b[$n]["type"];
			$filename = $b[$n]["filename"];

		break;
		case ("payload") :
			$a = $DB->fetch_one(
				sprintf($SQL_GET_CONTENT_PAYLOAD, $_SESSION["config_id"], $no));

			if ($a["isPayload"] == 0) exit;

			$b = parseContent($a["headerPayload"], "payload");
			$data = retrieveContent($a["payload"], $n, "payload");

			$type = $b[$n]["type"];
			$filename = $b[$n]["filename"];

		break;
		case ("html") :

			$Template = new Template;

			// return html body with frame or no frame
			$a = $DB->fetch_one(
				sprintf($SQL_GET_CONTENT_HTML, $_SESSION["config_id"], $no));

			if ($a["isCid"]) $f = parseContent($a["headerCid"], "cid"); // check cid

			$data = $a["htmlBody"];
			$n = count($f);
			for ($i = 0; $i < $n; $i++) {

				$h = $_SESSION["user_www_url"] .
					"/module/message/action/getContent?method=cid&no=" . $no . "&n=" . $i;

				$data = ereg_replace("cid:" . $f[$i]["id"], $h, $data);

				// prevent mugling of "img src script".
				$data =
					preg_replace("/<img class=\"mesian\" .*src=[a-z0-9\"']*script:[^>]+>/i",
					"", $data);
			}

			$type = "text/html";

			$data = reformat_html_message($data);
			// remove "delivery notification service" code
			if ($_SESSION["user_directory"] == $global["directory"]["sent"]) {
				$data = eregi_replace(
					sprintf("<img border=0 src=\"http://[a-z0-9./-][a-z0-9./-]*\?a=%s*&b=[0-9][0-9]*\" width=1 height=1>",
						$_SESSION["config_id"]), "", $data);
			}

			//$var["content"] = $data;
			//$tmpl = "/module/message/template/viewHtmlBody_with_no_frame";

			//$data = $Template->generate($tmpl, $var);
		break;
	}

	return $data;
}

?>
